@@ -209,8 +209,16 @@ class PDFExtractor:
             return True
         try:
             vacuumdir(tmpdir)
-            subprocess.check_call([self.pdftk, self.filename, "unpack_files",
-                                   "output", tmpdir])
+            # Note: the java version of pdftk sometimes/often fails
+            # here with writing to stdout: "Error occurred during
+            # initialization of VM". Maybe unsufficient resources when
+            # execd from Python ? In any case, the important thing is
+            # to discard the output, until we fix the error or
+            # preferably find a way to do it with poppler...
+            with open(os.devnull, 'w') as FNULL:
+                subprocess.check_call(
+                    [self.pdftk, self.filename, "unpack_files", "output",
+                     tmpdir], stdout=FNULL)
             self.attachlist = sorted(os.listdir(tmpdir))
             return True
         except Exception as e:
@@ -427,25 +435,33 @@ class PDFExtractor:
             for annot_mapping in annot_mappings:
                 atype = annot_mapping.annot.get_annot_type().value_name
                 if atype  != 'POPPLER_ANNOT_LINK':
-                    atext = f.format(
-                        pnum,
-                        annot_mapping.annot.get_modified(),
-                        annot_mapping.annot.get_annot_type().value_nick,
-                        annot_mapping.annot.get_contents()) + "\n"
-                    if pnum in abypage:
-                        abypage[pnum] += atext
-                    else:
-                        abypage[pnum] = atext
+                    # Catch because we sometimes get None values
+                    try:
+                        atext = f.format(
+                            pnum,
+                            annot_mapping.annot.get_modified(),
+                            annot_mapping.annot.get_annot_type().value_nick,
+                            annot_mapping.annot.get_contents()) + "\n"
+                        if pnum in abypage:
+                            abypage[pnum] += atext
+                        else:
+                            abypage[pnum] = atext
+                    except:
+                        pass
         #self.em.rclog("Annotations: %s" % abypage)
         pagevec = html.split(b"\f")
         html = b""
+        annotsfield = b""
         pagenum = 1
         for page in pagevec:
             html += page
             if pagenum in abypage:
                 html += abypage[pagenum].encode('utf-8')
+                annotsfield += abypage[pagenum].encode('utf-8') + b" - " 
             html += b"\f"
             pagenum += 1
+        if annotsfield:
+            self.em.setfield("pdfannot", annotsfield)
         return html
     
     def _selfdoc(self):
